@@ -51,12 +51,12 @@ def install():
 
             span.op = str(req.url).split("?")[0]
             span.peer = "%s:%s" % (req.remote_addr, req.port)
-            # span.tag(Tag(key=tags.HttpMethod, val=req.method))
-            # span.tag(Tag(key=tags.HttpUrl, val=str(req.url)))
-            # span.tag(Tag(key=tags.HttpPath, val=str(req.url).split("?")[0]))
+            span.tag(Tag(key=tags.HttpMethod, val=req.method))
+            span.tag(Tag(key=tags.HttpUrl, val=str(req.url)))
+            span.tag(Tag(key=tags.HttpPath, val=str(req.url).split("?")[0]))
             if req.params:
                 span.tag(
-                    Tag(key=tags.HttpParams, val=params_tostring(req.params)[0 : config.http_params_length_threshold])
+                    Tag(key=tags.HttpParams, val=params_tostring(req.params)[0:])
                 )
 
             set_code(config.tenant_code_reader, req, "tenant_code")
@@ -70,7 +70,6 @@ def install():
             return resp
 
     def _fast_handle_exception(this: API, req, resp, ex, params):
-        print("a9")
         if ex is not None:
             entry_span = get_context().active_span()
             if entry_span is not None and type(entry_span) is not NoopSpan:
@@ -95,7 +94,16 @@ def install():
         if reader_type == ReaderType.Cookie:
             code = request.cookies.get(reader.get("ReaderKey"), "")
         elif reader_type == ReaderType.RequestHeader:
-            code = request.headers[reader.get("ReaderKey")] if reader.get("ReaderKey") in request.headers else ""
+            # 下划线转中横杠
+            code = ""
+            if '_' in reader.get("ReaderKey"):
+                reader["ReaderKey"] = reader.get("ReaderKey").replace('_', '-')
+            if reader.get("ReaderKey") in request.headers:
+                code = request.headers[reader.get("ReaderKey")]
+            elif reader.get("ReaderKey").upper() in request.headers:
+                code = request.headers[reader.get("ReaderKey").upper()]
+            elif reader.get("ReaderKey").capitalize() in request.headers:
+                code = request.headers[reader.get("ReaderKey").capitalize()]
         elif reader_type == ReaderType.QueryString:
             # import json
             # raw = request.stream.read()
